import pytest
import subprocess

from kbase_report_state import serve


def test_serve():
    try:
        serve()
    except NotImplementedError as err:
        assert isinstance(err, NotImplementedError)

def test_serve_cli():
    output = subprocess.run("python kbase_report_state/__init__.py".split(" "), capture_output=True)
    print(f"output: {output}")



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['kbase_report_state']

package_data = \
{'': ['*']}

setup(name='kbase_report_state',
      version='0.0.9',
      description='API to Save KBase report state.',
      author=None,
      author_email='Dakota Blair <dblair@bnl.gov>',
      url=None,
      packages=packages,
      package_data=package_data,
      python_requires='>=3.8.2',
     )
